@@ -138,27 +138,39 @@ def convert_txt_to_pdf(file_path):
 
 def elem2dict(node):
     """
-    Convert an lxml.etree node tree into a dict.
+    Convert an xml.ElementTree node tree into a dict.
     """
     result = {}
 
-    for element in node.iterchildren():
-        # Remove namespace prefix
-        key = element.tag.split('}')[1] if '}' in element.tag else element.tag
+    for element in node:
+        key = element.tag
+        if '}' in key:
+            # Remove namespace prefix
+            key = key.split('}')[1]
+
+        if node.attrib:
+            result['@attribs'] = dict(node.items())
 
         # Process element as tree element if the inner XML contains non-whitespace content
         if element.text and element.text.strip():
             value = element.text
         else:
             value = elem2dict(element)
+        
+        # Check if a node with this name at this depth was already found
         if key in result:
-
-
-            if type(result[key]) is list:
-                result[key].append(value)
+            if type(result[key]) is not list:
+                # We've seen it before, but only once, we need to convert it to a list
+                try:
+                    tempvalue = result[key].copy()
+                    result[key] = [tempvalue, value]
+                except Exception:
+                    pass
             else:
-                tempvalue = result[key].copy()
-                result[key] = [tempvalue, value]
+                # We've seen it at least once, it's already a list, just append the node's inner XML
+                result[key].append(value)
         else:
+            # First time we've seen it
             result[key] = value
+
     return result
\ No newline at end of file
